@@ -8,11 +8,15 @@ use warnings;
 
 use experimental ( 'postderef', 'signatures' );
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Exporter 'import';
 
-our @EXPORT_OK   = qw[ iterator iter iarray icycle icache igrep imap iproduct iseq ifreeze thaw ];
+our @EXPORT_OK = qw[
+  iterator iter iarray icycle icache
+  icat igrep imap iproduct iseq ifreeze thaw
+];
+
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 use Ref::Util             qw[ is_arrayref is_hashref is_ref is_globref ];
@@ -155,6 +159,45 @@ sub icache ( $iterable, $pars = {} ) {
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+sub icat ( @args ) {
+    require Iterator::Flex::Cat;
+    Iterator::Flex::Cat->new( @args );
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -394,7 +437,7 @@ __END__
 
 =pod
 
-=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory
+=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory icat
 
 =head1 NAME
 
@@ -402,7 +445,7 @@ Iterator::Flex::Common - Iterator Generators and Adapters
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -557,6 +600,38 @@ The returned iterator supports the following methods:
 
 =back
 
+=head2 icat
+
+  $iterator = icat( \@iterables, ?\%pars );
+
+Concatenate the iterables.  As each iterator is exhausted, the next
+one is queried for its values.  See L<Iterator::Flex::Cat> for more
+details.
+
+The returned iterator supports the following methods:
+
+=over
+
+=item reset
+
+If all of the iterables support it.
+
+=item rewind
+
+If all of the iterables support it.
+
+=item next
+
+=item prev
+
+=item current
+
+=item freeze
+
+If all of the iterables support it.
+
+=back
+
 =head2 icycle
 
   $iterator = icycle( $array_ref, ?\%pars );
